#!/usr/bin/env python
# -*- coding: utf-8 -*-
#*****************************************************************************
#       Copyright (C) 2006 Serge Weinstock <serge.weinstock@ntlworld.com>>
#  Distributed under the terms of the BSD License.  The full license is in
#  the file COPYING, distributed as part of this software.
#*****************************************************************************
"""
All the application configuration related stuff
"""
from utils import property
from qt import QSize
from kmdi import KMdi
from kdecore import KApplication

MAX_THUMB_SIZE=200
IMAGE_SIZES = [800, 1600, 1920]

class ConfigBase(object):
    def __init__(self):
        self.cfg = KApplication.kApplication().config()
    def prep(self):
        self.cfg.setGroup(self.__class__.__name__)

class MainFrame(ConfigBase):
    """All the parameters related to the MainFrame"""
    _Str2MDIMode = {
        "IDEAlMode" : KMdi.IDEAlMode, "ChildframeMode": KMdi.ChildframeMode,
        "TabPageMode" : KMdi.TabPageMode, "ToplevelMode": KMdi.ToplevelMode,
        }
    _Str2MDIMode = dict([(v , k) for k , v in _Str2MDIMode.iteritems()])
    @property
    def MDImode(): #@NoSelf
        """The main frame mdi mode"""
        def fget(self):
            self.prep()
            return MainFrame._Str2MDIMode.get(self.cfg.readEntry("MDiMode"), KMdi.IDEAlMode)
        def fset(self, mode):
            self.prep()
            self.cfg.writeEntry("MDiMode", MainFrame._Str2MDIMode.get(mode, MainFrame._Str2MDIMode[KMdi.IDEAlMode]))
    @property
    def lastOpenDir(): #@NoSelf
        """The last directory where a file was open"""
        def fget(self):
            self.prep()
            return self.cfg.readEntry("lastOpenDir")
        def fset(self, lastdir):
            self.prep()
            self.cfg.writeEntry("lastOpenDir", lastdir)
    @property
    def lastSaveDir(): #@NoSelf
        """The last directory where a file was saved"""
        def fget(self):
            self.prep()
            return self.cfg.readEntry("lastSaveDir", self.lastOpenDir)
        def fset(self, lastdir):
            self.prep()
            self.cfg.writeEntry("lastSaveDir", lastdir)

class Batch(ConfigBase):
    """All the parameters related to the Batch conversion"""
    @property
    def size(): #@NoSelf
        """Size of the dialog"""
        def fget(self):
            self.prep()
            return self.cfg.readSizeEntry("size", QSize(0,0))
        def fset(self, size):
            self.prep()
            self.cfg.writeEntry("size", size)
    @property
    def recursive(): #@NoSelf
        """Recurse directories?"""
        def fget(self):
            self.prep()
            return self.cfg.readBoolEntry("recursive", True)
        def fset(self, recurse):
            self.prep()
            self.cfg.writeEntry("recursive", recurse)
    @property
    def overwriteMode(): #@NoSelf
        """Mode when a file already exits"""
        def fget(self):
            self.prep()
            return self.cfg.readNumEntry("overwrite", 0)
        def fset(self, overwrite):
            self.prep()
            self.cfg.writeEntry("overwrite", overwrite)
    @property
    def filterSizes(): #@NoSelf
        """Save images according to their sizes"""
        def fget(self):
            self.prep()
            default = [True, {MAX_THUMB_SIZE:False}]
            for i in IMAGE_SIZES:
                default[1][i] = True
            res = self.cfg.readEntry("filterSizes")
            try:
                res = eval(str(res))
                assert(isinstance(res[0], bool))
                assert(len(res[1]) == 1+len(IMAGE_SIZES))
                assert(isinstance(res[1][MAX_THUMB_SIZE], bool)) # throw an exception if the key doesn't exists
                for i in IMAGE_SIZES:
                    assert(isinstance(res[1][i], bool))
            except Exception:
                res = default
            return res
        def fset(self, filterSizes):
            self.prep()
            self.cfg.writeEntry("filterSizes", str(filterSizes))

class Config(object):
    """The configuration class"""
    def __init__(self):
        """Constructor"""
        self.mainframe = MainFrame()
        self.batch = Batch()
